@@ -1,3 +1,10 @@
+/**
+ * @file includes.h
+ * @brief Single file including all necessary system files.
+ * @date 12 sep 2017
+ * @author Sami Evangelista
+ */
+
 #ifndef LIB_INCLUDES
 #define LIB_INCLUDES
 
@@ -9,7 +16,6 @@
 #include "stdarg.h"
 #include "limits.h"
 #include "pthread.h"
-#include "semaphore.h"
 #include "assert.h"
 #include "malloc.h"
 #include "math.h"
@@ -23,6 +29,4 @@
 #include "signal.h"
 #include "stdint.h"
 
-#include "config.h"
-
 #endif
